/*  MaitreTarot.
 *  (C) 2002 Philippe Brochard <hocwp@free.fr>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef MT_GTK_CLIENT_GUI_CONFIG_H
#define MT_GTK_CLIENT_GUI_CONFIG_H

#include <gtk/gtk.h>
#include <mt_client.h>

extern GString *configfilename;

extern GString *gui_info_geometry;


extern void gui_save_config (void);

extern void gui_set_bg_color (void);
extern void gui_set_geometry (void);

#endif /* MT_GTK_CLIENT_GUI_CONFIG_H */
